package org.dbxml.client.xmldb.services;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: XUpdateQueryServiceImpl.java,v 1.7 2001/09/09 18:07:53 kstaken Exp $
 */

import org.dbxml.core.FaultCodes;
import org.dbxml.core.corba.db.*;
import org.dbxml.core.corba.*;
import org.dbxml.core.corba.db.Collection;
import org.dbxml.client.xmldb.*;

import org.dbxml.client.xmldb.resources.*;

import org.dbxml.xml.*;
import org.dbxml.xml.dom.*;

import org.w3c.dom.*;
import org.xmldb.api.base.*;
import org.xmldb.api.modules.*;

public class XUpdateQueryServiceImpl extends CommonConfigurable
   implements org.xmldb.api.modules.XUpdateQueryService
{
   private static final NamedVal[] EmptyNamedVals = new NamedVal[0];
   protected org.xmldb.api.base.Collection collection = null;

   public XUpdateQueryServiceImpl() {
   }

   public String getName() throws XMLDBException {
      return "XUpdateQueryService";
   }

   public String getVersion() throws XMLDBException {
      return "1.0";
   }

   public void setCollection(org.xmldb.api.base.Collection col)
         throws XMLDBException {
      this.collection = col;
   }

   public XMLResource updateResult(String commands) throws XMLDBException {
      // Get the dbXML collection object from the XML:DB collection wrapper.
      Collection col = ((CollectionImpl) collection).getServerObject();

      try {
         EncodedBuffer buffer = col.queryCollection("XUpdate", commands, EmptyNamedVals, -1);
         return new XMLResourceImpl("", collection, new String(buffer.buf));
      }
      catch (Exception e) {
         throw FaultCodes.createXMLDBException(e);
      }
   }

   /**
    * Runs a set of XUpdate operations against the collection. All selected
    * documents are to be updated and stored back to the repository.
    *
    * @param commands The XUpdate commands to use.
    * @return the number of nodes updated
    * @exception XMLDBException with expected error codes.<br />
    *  <code>ErrorCodes.VENDOR_ERROR</code> for any vendor
    *  specific errors that occur.<br />
    */
   public long update(String commands) throws XMLDBException {
      XMLResource result = updateResult(commands);
      return getResultCount(result);
   }

   public XMLResource updateResourceResult(String id, String commands) throws XMLDBException {
      // Get the dbXML collection object from the XML:DB collection wrapper.
      Collection col = ((CollectionImpl) collection).getServerObject();

      try {
         EncodedBuffer buffer = col.queryDocument("XUpdate", commands, EmptyNamedVals, id, -1);
         return new XMLResourceImpl("", collection, new String(buffer.buf));
      }
      catch (Exception e) {
         throw FaultCodes.createXMLDBException(e);
      }
   }

   /**
    * Runs a set of XUpdate operations against a resource stored in a
    * collection. The resource will be updated in place in the collection.
    *
    * @param commands The XUpdate commands to use.
    * @return the number of nodes updateds
    * @exception XMLDBException with expected error codes.<br />
    *  <code>ErrorCodes.VENDOR_ERROR</code> for any vendor
    *  specific errors that occur.<br />
    */
   public long updateResource(String id, String commands) throws XMLDBException {
      XMLResource result = updateResourceResult(id, commands);
      return getResultCount(result);
   }
   
   protected long getResultCount(XMLResource resource) throws XMLDBException {      
      Document doc = (Document) resource.getContentAsDOM();
      // Get the src:modified element
      Node node = doc.getDocumentElement().getFirstChild();
      // The count is a text node within the element.
      String count = node.getFirstChild().getNodeValue();
      
      try {
         return Long.parseLong(count);
      }
      catch (Exception e) {
         return 0;
      }
   }
}

