package org.dbxml.core;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: Container.java,v 1.11 2001/06/07 01:12:33 tom Exp $
 */

import org.w3c.dom.*;
import org.dbxml.core.data.*;
import org.dbxml.server.*;

/**
 * Container is a generic container for Key and Document pairs.
 */

public interface Container {
   /**
    * getCollection returns the Collection that the Document contained
    * belongs to.
    *
    * @return The owner Collection
    */
   Collection getCollection();
   
   /**
    * getKey returns the Document Key.
    *
    * @return The Document Key
    */
   Key getKey();
   
   /**
    * getCanonicalName returns the canonical name for the contained
    * Document.
    * <br>
    * ex: /local/test/ocs/ytd
    *
    * @return The canonical name
    */
   String getCanonicalName() throws DBException;
   
   /**
    * getDocument returns the contained Document.
    *
    * @return The Document
    */
   Document getDocument();
   
   /**
    * rollback reloads the Document from the Collection.
    *
    * @return The Document
    */
   Document rollback() throws DBException;
   
   /**
    * delete removes the Document from the Collection.
    */
   void remove() throws DBException;
   
   /**
    * commit saves the Document in the Collection.
    */
   void commit() throws DBException;
   
   /**
    * commit replaces the Document in the Collection with the
    * specified Document.
    *
    * @param document The Document
    */
   void commit(Document document) throws DBException;
}

