package org.dbxml.core.corba;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: DatabaseServant.java,v 1.12 2001/06/03 03:20:30 tom Exp $
 */

import org.dbxml.core.corba.db.*;
import org.dbxml.core.FaultCodes;
import org.dbxml.server.*;

/**
 * Database CORBA wrapper for org.dbxml.core.Database
 * For detailed documentation
 * @see org.dbxml.core.Database
 */

public class DatabaseServant extends DatabasePOA {
   protected org.dbxml.core.Database db;
   protected Kernel kernel;

   public DatabaseServant(org.dbxml.core.Database db, Kernel kernel) {
      this.db = db;
      this.kernel = kernel;
   }

   public String getName () throws APIException {
      try {
         return db.getName();
      }
      catch (Exception e) {
         throw FaultCodes.createAPIException(e);
      }
   }

   public DatabaseManager getDatabaseManager() throws APIException {
      try {
         return new DatabaseManagerServant(db, kernel)._this(_orb());
      }
      catch (Exception e) {
         throw FaultCodes.createAPIException(e);
      }
   }

   public String[] listCollections () throws APIException {
      try {
         return db.listCollections();
      }
      catch (Exception e) {
         throw FaultCodes.createAPIException(e);
      }
   }

   public org.dbxml.core.corba.db.Collection getCollection (String nam)
         throws APIException {
      org.dbxml.core.Collection col = null;
      try {
         col = db.getCollection(nam);
      }
      catch (Exception e) {
         throw FaultCodes.createAPIException(e);
      }

      if (col != null) {
         return new CollectionServant(col)._this(_orb());
      }
      else {
         throw FaultCodes.createAPIException(FaultCodes.COL_COLLECTION_NOT_FOUND);
      }
   }

   /*
    * Releases all resources associated with this object
    */
   public void remove() {
   }
}
