package org.dbxml.core.data;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: Key.java,v 1.14 2001/05/23 00:34:47 tom Exp $
 */

import java.io.*;

/**
 * Key extends Value by providing a hash value for the Key.
 */

public final class Key extends Value {
   private int hash = 0;

   public Key(Value value) {
      super(value);
      calculateHash();
   }

   public Key(byte[] data) {
      super(data);
      calculateHash();
   }

   public Key(byte[] data, int pos, int len) {
      super(data, pos, len);
      calculateHash();
   }

   public Key(String data) {
      super(data);
      calculateHash();
   }

   // TODO: This has to be revisited
   private void calculateHash() {
      hash = 0;
      int pl = pos+len;
      for ( int i = pos; i < pl; i++ ) {
         hash = (hash << 5) ^ data[i];
         hash = hash % 1234567891;
      }
      hash = Math.abs(hash);
   }

   public int getHash(){
       return hash;
   }

   public boolean equals(Value value) {
      if ( value instanceof Key ) {
         Key key = (Key)value;
         return hash == key.hash ? compareTo(key) == 0
                                 : false;
      }
      else
         return super.equals(value);
   }

   public int hashCode() {
      return hash;
   }

   public boolean equals(Object obj) {
      if ( obj instanceof Key )
         return equals((Key)obj);
      else
         return super.equals(obj);
   }
}

