package org.dbxml.core.data;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: Record.java,v 1.7 2001/06/24 21:37:22 tom Exp $
 */

import java.util.Map;

/**
 * Record is a container for Key/Value pairs.  Record also provides
 * metadata for a Value stored in the database.
 */

public final class Record {
   public static final String CREATED = "created";
   public static final String MODIFIED = "modified";
   public static final String OWNER = "owner";
   public static final String GROUP = "group";
   
   private Key key = null;
   private Value value = null;
   private Map meta = null;

   public Record() {
   }

   public Record(Key key, Value value, Map meta) {
      this.key = key;
      this.value = value;
      this.meta = meta;
   }
   
   public Record(Key key, Value value) {
      this.key = key;
      this.value = value;
   }

   /**
    * getKey returns the Record's Key.
    *
    * @return The Record's Key
    */
   public Key getKey() {
      return key;
   }

   /**
    * setValue sets the Record's Value.
    *
    * @param value The new Value
    */
   public void setValue(Value value) {
      this.value = value;
   }

   /**
    * setValue sets the Record's Value.
    *
    * @param value The new Value
    */
   public void setValue(String value) {
      this.value = new Value(value);
   }

   /**
    * getValue returns the Record's Value.
    *
    * @return The Record's Value
    */
   public Value getValue() {
      return value;
   }
   
   /**
    * getMetaData returns metadata about the Value.
    *
    * @param name The property name
    * @return The metadata value
    */
   public Object getMetaData(Object name) {
      return meta != null ? meta.get(name)
                          : null;
   }
}
