package org.dbxml.core.query;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: Query.java,v 1.8 2001/08/03 06:33:58 tom Exp $
 */

import org.dbxml.core.*;
import org.dbxml.core.data.*;
import org.dbxml.xml.*;

import org.w3c.dom.*;

/**
 * Query represents a compiled (parsed and primed) query.
 */

public interface Query {
   /**
    * getQueryStyle returns the QueryStyle (ex: XPath) for this Query
    * instance.
    *
    * @return The Query style
    */
   String getQueryStyle();

   /**
    * getQueryContext returns the Collection context for this query.
    *
    * @return The Collection context
    */
   Collection getQueryContext();

   /**
    * getQueryString returns the String that was used to create the
    * Query instance.
    *
    * @return The Query String
    */
   String getQueryString();

   /**
    * getNamespaceMap returns the Map for prefixed namespace
    * resolution in relation to this Query.
    *
    * @return The namespace Map (if any)
    */
   NamespaceMap getNamespaceMap();

   /**
    * getKeySet returns the initial set of Keys for this Query.
    *
    * @return The initial Key set (if any)
    */
   Key[] getKeySet();
   
   /**
    * execute actually Executes the query and returns the resulting
    * NodeSet.
    *
    * @return The NodeSet
    */
   NodeSet execute() throws QueryException;
   

}
