package org.dbxml.core.query;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: QueryResolver.java,v 1.12 2001/08/03 06:33:59 tom Exp $
 */

import org.dbxml.core.*;
import org.dbxml.core.data.*;
import org.dbxml.server.*;
import org.dbxml.xml.*;

import org.w3c.dom.*;

/**
 * QueryResolver is an interface that has to be implemented to actually
 * perfrom query resolution.  dbXML provides an XPathQueryResolver to
 * handle XPath queries against sets of Documents in a Collection.
 */

public interface QueryResolver extends Configurable {
   /**
    * setQueryEngine hands a reference for the QueryEngine to the
    * Resolver.
    *
    * @param engine The QueryEngine
    */
   void setQueryEngine(QueryEngine engine);

   /**
    * getQueryStyle returns the Query style supported by this Resolver.
    *
    * @return The query style
    */
   String getQueryStyle();

   /**
    * compileQuery compiles a Query against the specified Collection
    * context and returns the compiled Query.  This DOES NOT actually
    * run the query, merely just parses it and primes any possible
    * Indexers that the query might need.
    *
    * @param context The Collection Context
    * @param query The Query
    * @param nsMap The namespace Map (if any)
    * @param keys The initial Key set to use (if any)
    * @return The compiled Query
    */
   Query compileQuery(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException;

   /**
    * query compiles a Query against the specified Collection context
    * and returns the query results.
    *
    * @param context The Collection Context
    * @param query The Query
    * @param nsMap The namespace Map (if any)
    * @param keys The initial Key set to use (if any)
    * @return The resulting NodeSet
    */
   NodeSet query(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException;
   
}
