package org.dbxml.tools.command;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: AddIndexer.java,v 1.24 2001/06/28 23:29:05 kalafus Exp $
 */

import java.util.Hashtable;

import org.xmldb.api.base.*;
import org.xmldb.api.DatabaseManager;

import org.dbxml.client.xmldb.*;
import org.dbxml.client.xmldb.services.*;

import org.dbxml.xml.TextWriter;

import org.dbxml.xml.*;
import org.dbxml.xml.dom.*;

import org.w3c.dom.*;

/**
 * AddIndexer.java is designed to let the user create an Indexer
 * and insert it into a Collection.
 */

public class AddIndexer extends Command {
    public boolean execute(Hashtable table ) throws Exception {
    
        Collection col = null;
        
        try {
        
            if (table.get("collection") != null) {

                // Get a Collection reference to the collection
                String colstring = normalizeCollectionURI( (String)table.get("collection") );
                col = DatabaseManager.getCollection( colstring );
                if ( col == null ) {
                  System.out.println("ERROR : Collection not found!");
                  return false;
                }
                    
                // Create a collection manager instance for the collection
                CollectionManager colman = (CollectionManager)col.getService("CollectionManager",XMLDBAPIVERSION);
    
                if (table.get("nameOf") != null && table.get("pattern") != null ) {
                
                    Document doc = new DocumentImpl();

                    // Create the index element to hold attributes
                    Element idxEle = doc.createElement("index");
                    idxEle.setAttribute("class", DBXML_VAL_INDEXER);
                    idxEle.setAttribute("name", (String)table.get("nameOf"));
                    idxEle.setAttribute("pattern", (String)table.get("pattern") );


                    // Setup optional index attributes
                    if ( table.containsKey("type") ) {
                        String t = (String)table.get("type");
                        if ( t.equalsIgnoreCase("name") )
                           idxEle.setAttribute("class", DBXML_NAME_INDEXER);
                        else
                           idxEle.setAttribute("type", (String)table.get("type"));
                    }

                    if ( table.containsKey("pagesize") ) {
                        idxEle.setAttribute("pagesize", (String)table.get("pagesize"));
                    }

                    if (table.containsKey("maxkeysize") ) {
                        idxEle.setAttribute("maxkeysize", (String)table.get("maxkeysize") );
                    }

                    // Add Element to the document
                    doc.appendChild(idxEle);
                        
                    //If in verbose mode, show....
                    if ( (String)table.get("verbose") == "true" ) {
                        String indexstr = TextWriter.toString(doc);
                        System.out.println("Index node element = ");
                        System.out.println("\t" + indexstr + "\n" );
                    }
                    

                    // Create the indexer for this collection manager
                    colman.createIndexer(doc);

                    System.out.println("CREATED : " + table.get("nameOf"));
                    
                }
                else {
                    System.out.println("ERROR : Name and Pattern required");
                }

            }
            else {
                System.out.println("ERROR : Collection and switch required");
            }

        } catch (Exception e) {
            System.out.println("ERROR : " + e.getMessage() );
            if (table.get("verbose").equals("true")) {
                e.printStackTrace(System.out);
            }
            return false;
            
        } finally {
            if ( col != null ) {
                col.close();
            }
        }
        
        return true;
    }
    
}



