package org.dbxml.tools.command;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: Command.java,v 1.25 2001/09/04 11:13:48 kstaken Exp $
 */

import java.util.Hashtable;
import org.dbxml.server.dbXMLException;
import org.xmldb.api.base.*;

/**
 * Command is the standard interface command line arguments
 */

public abstract class Command {
   
   // Collection manager path to instantiate
   public static final String DBXMLURI="dbxml:///";
   public static final String COLLECTIONURI="xmldb:" + DBXMLURI;
   
   // Version of the XML:DB API that we are using
   public static final String XMLDBAPIVERSION="1.0";
   
   // Class name of the Standar DBXML Indexer
   public static final String DBXML_VAL_INDEXER="org.dbxml.core.indexer.ValueIndexer";
   public static final String DBXML_NAME_INDEXER="org.dbxml.core.indexer.NameIndexer";
   
   //public boolean execute(Hashtable table, Database db)
   public abstract boolean execute(Hashtable table) throws Exception;

   // public class to return normalized CollectionURI for creation of a Collection object
   public String normalizeCollectionURI(String uri) {
      // Check to see if this uri starts with "xmldb:" , if so treat as absolute
      if ( uri.startsWith("xmldb:") ) {
         // URI is absolute, leave alone
         return uri;
      }
      else {
         // URI passed in is not absoulte, prepend COLLECTIONURI to it, remove leading "/"
         return ( COLLECTIONURI + uri.substring(1) );
      }
   }

   // public class to return normalized CollectionURI for creation of a Collection object
   public String normalizeDbXmlURI(String uri) throws dbXMLException {

      // Check to see if this uri starts with "xmldb:" , if so treat as absolute
      if ( uri.startsWith("dbxml:") ) {
         // URI is absolute, leave alone
         return uri;
      }
      else {
         return ( DBXMLURI + uri.substring(1) );
      }
   }


} //interface Command

