package org.dbxml.tools.command;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: RetrieveDocument.java,v 1.39 2001/06/28 23:29:06 kalafus Exp $
 */

import java.util.Hashtable;
import java.io.*;

import org.xmldb.api.modules.*;
import org.dbxml.client.xmldb.services.*;

import org.xmldb.api.base.*;
import org.xmldb.api.DatabaseManager;

import org.w3c.dom.*;

/**
 * RetrieveDocument.java is designed to let the user recall or
 * retrieve a Document from a specific Collection and save it to a new location.
 */

public class RetrieveDocument extends Command {
    public boolean execute(Hashtable table ) throws Exception {

        Collection col = null;

        try {

            if (table.get("collection") != null) {
               //col = db.getCollection((String)table.get("collection"));
               // Create a collection instance
               String colstring = normalizeCollectionURI( (String)table.get("collection") );
               String docname = (String)table.get("nameOf");

               col = DatabaseManager.getCollection( colstring );
               // Make sure that the collection was found
               if ( col == null ) {
                  System.out.println("ERROR : Collection not found!");
                  return false;
               }

               if (table.get("nameOf") != null) {

                  XMLResource resource = (XMLResource)col.getResource(docname);
                  // Verify that we were able to find the document
                  if ( resource == null ) {
                     System.out.println("ERROR : Document not found!");
                     return false;
                  }
                    
                  String documentstr = (String)resource.getContent();

                  if ((documentstr != null) && (table.get("filePath") != "" )) {
                     try {
                        File file = new File((String)table.get("filePath"));
                        // Create the directory structure if necessary
                        if( file.getParentFile() != null ) {
                           file.getParentFile().mkdirs();
                        }
                         
                        FileOutputStream out = new FileOutputStream(file);
                        
                        System.out.println("Writing...");
                        
                        out.write(documentstr.getBytes());
                        out.close();
                        
                        System.out.println("Wrote file " + table.get("filePath") );

                     } catch (IOException ie) {
                         System.out.println("ERROR : " + ie);
                         return false;
                     
                     } catch (NullPointerException np) {
                         System.out.println("ERROR : " + np);
                         System.out.println("No file destination given");
                         return false;
                     }
                  }
                  else {
                     // Send to stdout
                     System.out.println(documentstr);
                  }
               }
               else {
                  System.out.println("ERROR : Document Key required");
               }
            }
            else{
               System.out.println("ERROR : Collection context required");
            }

         } catch (Exception e) {
            System.out.println("ERROR : " + e.getMessage() );
            if (table.get("verbose").equals("true")) {
               e.printStackTrace(System.out);
            }
            return false;
            
         } finally {
            // Release the collection object
            if ( col != null ) {
               col.close();
            }
         }

      return true;
   }
   
}

