package org.dbxml.tools.command;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: XPathQuery.java,v 1.9 2001/08/08 04:57:40 kstaken Exp $
 */

import java.util.Hashtable;
import java.io.*;

import org.xmldb.api.modules.*;
import org.dbxml.client.xmldb.services.*;

import org.xmldb.api.base.*;
import org.xmldb.api.DatabaseManager;

import org.dbxml.xml.TextWriter;

import org.w3c.dom.*;

/**
 * SingleDocumentQuery is designed to enable the user/admin to XPathQuery a Collection for a Single Document.
 */

public class XPathQuery extends Command {

    public boolean execute(Hashtable table ) throws Exception {
        Collection col = null;
        
        try {
            
            if ( (String)table.get("collection") == null ) {
                System.out.println("ERROR : Collection name and switch required");
                return false;
            }

            if ( (String)table.get("query") == "" ) {
                System.out.println("ERROR : Query and switch required");
                return false;
            }
            
            String colstring = normalizeCollectionURI( (String)table.get("collection") );
            String querystring = (String)table.get("query");
            XPathQueryService service = null;
            ResourceIterator results = null;

            col = DatabaseManager.getCollection( colstring );
            
            if ( col == null ) {
               System.out.println("ERROR : Collection not found!");
               return false;
            }
            
            service = (XPathQueryService)col.getService("XPathQueryService","1.0");
            ResourceSet resultSet = service.query(querystring);
            results = resultSet.getIterator();
            
            while (results.hasMoreResources() ) {
                XMLResource resource = (XMLResource)results.nextResource();
                String documentstr = (String)resource.getContent();
                System.out.println(documentstr);
            }
            
        } catch (Exception e) {
            System.out.println("ERROR : " + e.getMessage() );
            if (table.get("verbose").equals("true")) {
                org.dbxml.Debug.printStackTrace(e);
            }
            return false;
            
        } finally {
            if ( col != null ) {
                col.close();
            }
        }
        
      return true;
   }

}


