package org.dbxml.xml.dom;

/*
 * dbXML License, Version 1.0
 *
 *
 * Copyright (c) 1999-2001 The dbXML Group, L.L.C.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by
 *        The dbXML Group (http://www.dbxml.com/)."
 *    Alternately, this acknowledgment may appear in the software
 *    itself, if and wherever such third-party acknowledgments normally
 *    appear.
 *
 * 4. The names "dbXML" and "The dbXML Group" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    info@dbxml.com.
 *
 * 5. Products derived from this software may not be called "dbXML",
 *    nor may "dbXML" appear in their name, without prior written
 *    permission of The dbXML Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE DBXML GROUP OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: TextImpl.java,v 1.6 2001/06/06 21:40:31 tom Exp $
 */

import org.w3c.dom.*;

/**
 * TextImpl
 */

public class TextImpl extends CharacterDataImpl implements Text {
   public TextImpl() {
   }
   
   public TextImpl(NodeImpl parentNode, byte[] data, int pos, int len) {
      super(parentNode, data, pos, len);
   }

   public TextImpl(NodeImpl parentNode, boolean dirty) {
      super(parentNode, dirty);
   }

   public TextImpl(NodeImpl parentNode, String nodeValue) {
      super(parentNode, nodeValue);
   }

   public short getNodeType() {
      return Node.TEXT_NODE;
   }

   public String getNodeName() {
      return "#text";
   }

   /**
    * Breaks this <code>Text</code> node into two Text nodes at the specified
    * offset, keeping both in the tree as siblings. This node then only
    * contains all the content up to the <code>offset</code> point. And a new
    * <code>Text</code> node, which is inserted as the next sibling of  this
    * node, contains all the content at and after the <code>offset</code>
    * point.
    * @param offset The offset at which to split, starting from 0.
    * @return The new <code>Text</code> node.
    * @exception DOMException
    *   INDEX_SIZE_ERR: Raised if the specified offset is negative or greater
    *   than the number of characters in <code>data</code>.
    *   <br>NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
    */
   public final Text splitText(int offset) throws DOMException {
      String value = getNodeValue();
      checkReadOnly();
      try {
         String newValue = value.substring(0, offset);
         String oldValue = value.substring(offset+1);
         Text text = getOwnerDocument().createTextNode(newValue);
         setNodeValue(oldValue);
         getParentNode().insertBefore(text, this);
         setDirty();
         return text;
      }
      catch ( Exception e ) {
         throw EX_INDEX_SIZE;
      }
   }
}

